#!/usr/bin/python3

'''
Check if debian/versions is sane and generate substvars for numpy:Provides.
'''

import os
import re

def main():
    meson_build = 'numpy/_core/meson.build'
    data = {}
    with open(meson_build) as file:
        for line in file:
            line = line.strip()
            mo = re.match("(?i)^(C_ABI_VERSION|C_API_VERSION) *= *'(0x[0-9A-F]+)'", line)
            if mo:
                data[mo.group(1)] = int(mo.group(2), base=16)
                if "C_ABI_VERSION" in data and "C_API_VERSION" in data:
                    break
    with open('debian/versions') as file:
        for line in file:
            line = line.strip()
            if not line or line.startswith('#'):
                continue
            key, value = line.split(None, 1)
            data[key] = value
    assert data['abi'] == str(data['C_ABI_VERSION'] - 0x2000000), f"ABI version mismatch, update debian/versions; debian={data['abi']} vs numpy={str(data['C_ABI_VERSION'] - 0x2000000)}"
    assert data['api'] == str(data['C_API_VERSION']), f"API version mismatch, update debian/versions; debian={data['api']} vs numpy={str(data['C_API_VERSION'])}"
    print('numpy3:Provides=python3-numpy2-abi%s, python3-numpy-api%s' % (data['abi'], data['api']))

if __name__ == '__main__':
    main()



#!/usr/bin/python3
# Architecture-specific long double formats for
# cross compilation
#
# This script expects two positional argument
# 1. the meson cross file
# 2. the DEB_HOST_ARCH architecture name
#
import configparser
import sys


class CaseSensitiveConfigParser(configparser.ConfigParser):
    optionxform = staticmethod(str)


cross_file = CaseSensitiveConfigParser()
with open(sys.argv[1]) as f:
    cross_file.read_file(f)

cross_file["properties"]["longdouble_format"] = repr(
    {
        "amd64": "INTEL_EXTENDED_16_BYTES_LE",
        "arm64": "IEEE_QUAD_LE",
        "armel": "IEEE_DOUBLE_LE",
        "armhf": "IEEE_DOUBLE_LE",
        "hppa": "IEEE_DOUBLE_BE",
        "i386": "INTEL_EXTENDED_12_BYTES_LE",
        "m68k": "MOTOROLA_EXTENDED_12_BYTES_BE",
        "mips64el": "IEEE_QUAD_LE",
        "ppc64": "IBM_DOUBLE_DOUBLE_BE",
        "ppc64el": "IEEE_QUAD_LE",
        "riscv64": "IEEE_QUAD_LE",
        "s390x": "IEEE_QUAD_BE",
        "sparc64": "IEEE_QUAD_BE",
    }.get(sys.argv[2], "UNKNOWN")
)

with open(sys.argv[1], "w") as f:
    cross_file.write(f)



#!/usr/bin/python3
#
# Helper tool to add f2pyX.YY to `console_scripts` section in entry_points.txt
#
# it expects 3 positional arguments:
#
# 1. the path to the `entry_points.txt` script
# 2. the option name to set
# 3. the value associated with that option name

import configparser
import sys


class CaseSensitiveConfigParser(configparser.ConfigParser):
    optionxform = staticmethod(str)


entry_points = CaseSensitiveConfigParser()
entry_points.read_file(open(sys.argv[1]))

if (sys.argv[2], sys.argv[3]) not in entry_points.items('console_scripts'):
    entry_points.set('console_scripts', sys.argv[2], sys.argv[3])


with open(sys.argv[1], 'w') as f:
    entry_points.write(f)

